Tester:
    resource_title: testers
    item_title: tester
    url: tester
    datasource:
        source: tester
    additional_lookup:
        url: string
        field: required_string
    cache_control: "max-age=10,must-revalidate"
    cache_expires: 10
    schema:
        required_string: {type: string, required: true, unique: true}
        string: {type: string}
        number: {type: number}
        media: {type: media}




EXPERIMENTS = {
    "xenonnt": {
        "url_prefix": "",
        "name_suffix": "",
        "mongo_prefix": "MONGO",
        "detectors":  ["tpc", "nveto", "muveto"],
    },
    "xenon1t": {
        "url_prefix": "xenon1t",
        "name_suffix": "1t",
        "mongo_prefix": "MONGO",
        "detectors": ["tpc", "muveto"],
    },
}

INCLUDE_AS_IS = ["accounts",]


"""Main module."""
import os
import pathlib
from .utils import read_endpoint_files, resources_from_templates

SOURCE_DIR = pathlib.Path(__file__).parent
DEFAULT_TEMPLATE_DIR = SOURCE_DIR / "endpoint_templates"

def get_endpoints(template_dir=DEFAULT_TEMPLATE_DIR.absolute(), endpoint_dir=None):
    templates = read_endpoint_files(template_dir)
    endpoints = resources_from_templates(templates)
    if endpoint_dir:
        endpoints.update(read_endpoint_files(endpoint_dir))
    return endpoints
